@@ -47,30 +47,44 @@ class FakeClient(object):
         return self.response
 
 
-@pytest.fixture
-def batch():
-    return FakeBatch()
+class ExceptionalClient(object):
+    def send_batch(self, *args, **kwargs):
+        raise RuntimeError("oops")
+
+
+class FakeEventBatch(FakeBatch):
+    def flush(self):
+        results = super(FakeEventBatch, self).flush()
+        return results[:1]
+
+
+class FakeEventClient(FakeClient):
+    def send_batch(self, items):
+        return super(FakeEventClient, self).send_batch(items)
+
+
+@pytest.fixture(params=((FakeClient, FakeBatch), (FakeEventClient, FakeEventBatch)))
+def harvester_args(request):
+    client_cls, event_cls = request.param
+    return client_cls(), event_cls()
 
 
 @pytest.fixture
-def client():
-    return FakeClient()
-
-
-@pytest.fixture
-def harvester(client, batch):
-    harvester = Harvester(client, batch)
+def harvester(harvester_args):
+    harvester = Harvester(*harvester_args)
     return harvester
 
 
-def test_record(harvester, batch):
+@pytest.mark.filterwarnings("ignore:.*Harvester.record.*:DeprecationWarning")
+def test_record(harvester):
     item = object()
     harvester.record(item)
-    assert batch.contents == [item]
+    assert harvester.batch.contents == [item]
 
 
-def test_run_once(harvester, client):
+def test_run_once(harvester):
     harvester.harvest_interval = 0
+    client = harvester._client
     send_batch = client.send_batch
 
     def shutdown_after_send(*args, **kwargs):
@@ -80,36 +94,45 @@ def test_run_once(harvester, client):
 
     client.send_batch = shutdown_after_send
     item = object()
-    harvester.record(item)
+    harvester.batch.record(item)
 
-    harvester.run()
+    harvester.start()
+    harvester.stop(timeout=0.1)
 
     assert client.sent == [((item,), None)]
 
 
-def test_run_flushes_data_on_shutdown(harvester, batch, client):
+def test_run_flushes_data_on_shutdown(harvester):
+    client = harvester._client
+
     item = object()
-    harvester.record(item)
+    harvester.batch.record(item)
 
     # Set shutdown event
     harvester._shutdown.set()
 
     assert not client.sent
-    harvester.run()
+    harvester.start()
+    harvester.stop(timeout=0.1)
     assert client.sent == [((item,), None)]
 
 
-def test_empty_items_not_sent(harvester, client):
+def test_empty_items_not_sent(harvester):
+    client = harvester._client
+
     # Set shutdown event
     harvester._shutdown.set()
 
-    harvester.run()
+    harvester.start()
+    harvester.stop(timeout=0.1)
 
     # Send is never called if the batch is empty
     assert not client.sent
 
 
-def test_harvester_terminates_at_shutdown(harvester, client):
+def test_harvester_terminates_at_shutdown(harvester):
+    client = harvester._client
+
     # Set the interval high enough so that send is never called unless shutdown
     # occurs
     harvester.harvest_interval = 99999
@@ -118,7 +141,7 @@ def test_harvester_terminates_at_shutdown(harvester, client):
     assert harvester.is_alive()
 
     item = object()
-    harvester.record(item)
+    harvester.batch.record(item)
 
     assert not client.sent
     harvester.stop(0.1)
@@ -126,13 +149,16 @@ def test_harvester_terminates_at_shutdown(harvester, client):
     assert client.sent == [((item,), None)]
 
 
-def test_harvester_handles_send_exception(caplog, batch):
+def test_harvester_handles_send_exception(caplog):
+    batch = FakeBatch()
+
     # Cause an exception to be raised since send_batch doesn't exist on object
     harvester = Harvester(object(), batch)
 
-    harvester.record(None)
+    harvester.batch.record(None)
     harvester._shutdown.set()
-    harvester.run()
+    harvester.start()
+    harvester.stop(timeout=0.1)
 
     assert (
         "newrelic_telemetry_sdk.harvester",
@@ -141,13 +167,15 @@ def test_harvester_handles_send_exception(caplog, batch):
     ) in caplog.record_tuples
 
 
-def test_harvester_send_failed(caplog, harvester, client):
+def test_harvester_send_failed(caplog, harvester):
+    client = harvester._client
     client.response.status = 500
     client.response.ok = False
 
-    harvester.record(None)
+    harvester.batch.record(None)
     harvester._shutdown.set()
-    harvester.run()
+    harvester.start()
+    harvester.stop(timeout=0.1)
 
     assert (
         "newrelic_telemetry_sdk.harvester",
