@@ -17,6 +17,7 @@ from newrelic_telemetry_sdk.metric import Metric, CountMetric, SummaryMetric
 from utils import CustomMapping
 
 
+@pytest.mark.filterwarnings("ignore:.*Metric.from_value.*:DeprecationWarning")
 @pytest.mark.parametrize("method", (None, "from_value"))
 def test_metric_defaults(method, freeze_time):
     new = Metric
@@ -32,6 +33,7 @@ def test_metric_defaults(method, freeze_time):
     assert "interval.ms" not in metric
 
 
+@pytest.mark.filterwarnings("ignore:.*interval_ms.*:DeprecationWarning")
 def test_count_metric_defaults(freeze_time):
     metric = CountMetric("name", 0)
     assert metric["type"] == "count"
@@ -44,6 +46,7 @@ def test_count_metric_defaults(freeze_time):
     assert "interval.ms" not in metric
 
 
+@pytest.mark.filterwarnings("ignore:.*interval_ms.*:DeprecationWarning")
 def test_summary_metric_defaults(freeze_time):
     metric = SummaryMetric("name", 0, 0, 0, 0)
     assert metric["type"] == "summary"
@@ -111,6 +114,7 @@ def test_metric_copy():
     assert copy is not original
 
 
+@pytest.mark.filterwarnings("ignore:.*Metric.from_value.*:DeprecationWarning")
 def test_summary_metric_from_value():
     metric = SummaryMetric.from_value("foo", 3)
     assert len(metric["value"]) == 4
